postgres.PostgresStore

|  | ## Cheshire3 Object Model: Class PostgresStore

Module postgres :: Class PostgresStore

## Class PostgresStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
        baseStore.SimpleStore --+
                                |
                               PostgresStore

Known Subclasses:
  PostgresIndexStore, PostgresRecordStore, PostgresResultSetStore

Instance Methods

__init__(self, session, config, parent) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
_handleConfigNode(self, session, node)
_verifyDatabases(self, session)
_openContainer(self, session)
_closeContainer(self, session)
query(self, query)
begin_storing(self, session)
commit_storing(self, session)
generate_id(self, session)
store_data(self, session, id, data, size=0)
verify_checkSum(self, session, id, data, store=1)
store_checkSum(self, session, id, digest)
fetch_data(self, session, id)
delete_item(self, session, id)
fetch_size(self, session, id)
fetch_checksum(self, session, id)
fetch_idList(self, session, numReq=-1, start="")
link(self, session, relation, *args, **kw)
unlink(self, session, relation, *args, **kw)
get_links(self, session, relation, *args, **kw)
Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

cxn |
relations |
Inherited from `baseStore.SimpleStore`: `currentId`, `idNormalizer` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, config, parent) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: baseStore.SimpleStore.__init__

### _handleConfigNode(self, session, node) | source code
Overrides: configParser.C3Object._handleConfigNode

### _verifyDatabases(self, session) | source code
Overrides: baseStore.SimpleStore._verifyDatabases

### _openContainer(self, session) | source code

### _closeContainer(self, session) | source code

### query(self, query) | source code

### begin_storing(self, session) | source code

### commit_storing(self, session) | source code

### generate_id(self, session) | source code

### store_data(self, session, id, data, size=0) | source code

### verify_checkSum(self, session, id, data, store=1) | source code

### store_checkSum(self, session, id, digest) | source code

### fetch_data(self, session, id) | source code

### delete_item(self, session, id) | source code

### fetch_size(self, session, id) | source code

### fetch_checksum(self, session, id) | source code

### fetch_idList(self, session, numReq=-1, start="") | source code

### link(self, session, relation, *args, **kw) | source code

### unlink(self, session, relation, *args, **kw) | source code

### get_links(self, session, relation, *args, **kw) | source code

Class Variable Details

    ### cxn Value:
        None

    ### relations Value:
        {}